@@ -335,7 +335,7 @@ requires = [ "whey",]
 build-backend = "whey"
 
 [project]
-name = "default_values"
+name = "DeFaUlT.values"
 version = "0.5.0"
 description = "Sphinx extension to show default values in documentation."
 readme = "README.rst"
@@ -397,6 +397,7 @@ def test_build_editable_namespace(
 
 		wheel = wheel_builder.build_editable()
 
+	assert wheel == "default_values-0.5.0-py3-none-any.whl"
 	assert (tmp_pathplus / wheel).is_file()
 
 	with handy_archives.ZipFile(tmp_pathplus / wheel) as zip_file:
@@ -687,7 +688,10 @@ def test_build_wheel_from_sdist(
 	(tmp_pathplus / "sdist_unpacked").mkdir()
 
 	with handy_archives.TarFile.open(tmp_pathplus / sdist) as sdist_tar:
-		sdist_tar.extractall(path=tmp_pathplus / "sdist_unpacked")
+		sdist_tar.extractall(
+				path=tmp_pathplus / "sdist_unpacked",
+				filter=handy_archives.fully_trusted_filter,
+				)
 
 	capsys.readouterr()
 	data: Dict[str, Any] = {}
@@ -1127,7 +1131,10 @@ def test_build_wheel_from_sdist_source_dir(
 	(tmp_pathplus / "sdist_unpacked").mkdir()
 
 	with handy_archives.TarFile.open(tmp_pathplus / sdist) as sdist_tar:
-		sdist_tar.extractall(path=tmp_pathplus / "sdist_unpacked")
+		sdist_tar.extractall(
+				path=tmp_pathplus / "sdist_unpacked",
+				filter=handy_archives.fully_trusted_filter,
+				)
 
 	capsys.readouterr()
 	data: Dict[str, Any] = {}
